from django.views.generic.base import View
from django.views.generic.detail import SingleObjectMixin, DetailView

from passerelle.utils import to_json
from passerelle import utils

from .models import Concerto


class ConcertoDetailView(DetailView):
    model = Concerto


class FamilyLink(View, SingleObjectMixin):
    model = Concerto

    @utils.protected_api('can_use_connector')
    @to_json('api')
    def get(self, request, slug, family_id, secret, *args, **kwargs):
        return self.get_object().family_link(family_id, secret)

class FamilyData(View, SingleObjectMixin):
    model = Concerto

    @utils.protected_api('can_use_connector')
    @to_json('api')
    def get(self, request, slug, nameid):
        data_filter = request.GET.get('filter', None)
        return self.get_object().family_data(nameid, data_filter)

class LinkToFamily(View, SingleObjectMixin):
    model = Concerto

    @utils.protected_api('can_use_connector')
    @to_json('api')
    def get(self, request, slug, nameid, family_id):
        return self.get_object().link_to_family(nameid, family_id)

class UnlinkFromFamily(View, SingleObjectMixin):
    model = Concerto

    @utils.protected_api('can_use_connector')
    @to_json('api')
    def get(self, request, slug, nameid):
        return self.get_object().unlink_from_family(nameid)

class FamilyInvoices(View, SingleObjectMixin):
    model = Concerto

    @utils.protected_api('can_use_connector')
    @to_json('api')
    def get(self, request, slug, nameid):
        status = request.GET.get('status', 'all')
        return self.get_object().family_invoices(nameid, status)

class InvoiceView(View, SingleObjectMixin):
    model = Concerto

    @utils.protected_api('can_use_connector')
    @to_json('api')
    def get(self, request, slug, invoice_id, invoice_hash):
        return self.get_object().get_invoice(invoice_id, invoice_hash)

    @utils.protected_api('can_use_connector')
    @to_json('api')
    def post(self, request, slug, invoice_id, invoice_hash):
        invoice_status = request.POST.get('status')
        return self.get_object().update_invoice(invoice_id, invoice_hash, invoice_status)
