import json

from django.core.urlresolvers import reverse
from django.views.generic.edit import CreateView, UpdateView, DeleteView
from django.views.generic.detail import DetailView, SingleObjectMixin
from django.views.generic.base import View

from passerelle import utils

from .models import CsvDataSource
from .forms import CsvDataSourceForm


class CsvDataSourceDetailView(DetailView):
    model = CsvDataSource


class CsvDataSourceCreateView(CreateView):
    model = CsvDataSource
    template_name = 'passerelle/manage/service_form.html'
    form_class = CsvDataSourceForm


class CsvDataSourceUpdateView(UpdateView):
    model = CsvDataSource
    template_name = 'passerelle/manage/service_form.html'
    form_class = CsvDataSourceForm


class CsvDataSourceDeleteView(DeleteView):
    model = CsvDataSource
    template_name = 'passerelle/manage/service_confirm_delete.html'

    def get_success_url(self):
        return reverse('manage-home')


class CsvDataView(View, SingleObjectMixin):
    model = CsvDataSource

    @utils.protected_api('can_access')
    @utils.to_json('api')
    def get(self, request, *args, **kwargs):
        obj = self.get_object()
        case_insensitive = 'case-insensitive' in request.GET
        query = request.GET.get('q')
        filters = {}
        for column_title in [t.strip() for t in obj.columns_keynames.split(',')]:
            if column_title in request.GET:
                filters[column_title] = request.GET[column_title]
        return obj.get_data(filters, query=query, case_insensitive=case_insensitive)
