import re
import urllib
import urllib2
import logging
import json

from django.utils.translation import ugettext_lazy as _
from django.db import models
from django.core.urlresolvers import reverse

from passerelle.base.models import BaseResource
from passerelle.sms import SMSGatewayMixin

from . import soap

class OrangeError(Exception):
    pass


class OrangeSMSGateway(BaseResource, SMSGatewayMixin):
    keystore = models.FileField(upload_to='orange',
            blank=True, null=True,
            verbose_name=_('Keystore'),
            help_text=_('Certificate and private key in PEM format'))
    default_country_code = '33'

    class Meta:
        verbose_name = 'Orange'
        db_table = 'sms_orange'

    @classmethod
    def get_icon_class(cls):
        return 'phone'

    def get_absolute_url(self):
        return reverse('orange-view', kwargs={'slug': self.slug})

    def get_edit_url(self):
        return reverse('edit-connector', kwargs={'connector': 'orange', 'slug': self.slug})

    def get_delete_url(self):
        return reverse('delete-connector', kwargs={'connector': 'orange', 'slug': self.slug})

    def send_msg(self, text, sender, destinations):
        logger = logging.getLogger('passerelle.apps.orange')
        """Send a SMS using the Orange provider"""
        # unfortunately it lacks a batch API...
        destinations = self.clean_numbers(destinations, self.default_country_code)

        logger.info(u'sending sms with sender %s to %s', sender, u', '.join(destinations))
        logger.debug(u'sms content: %s', text)
        #soap.ContactEveryoneSoap(instance=self).send_advanced_message(destinations, sender, text)
