# Passerelle - uniform access to data and services
# Copyright (C) 2015  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.conf.urls import patterns, include, url
from passerelle.urls_utils import decorated_includes, required, app_enabled
from django.contrib.auth.decorators import login_required

from .views import *

public_urlpatterns = patterns('',
    url(r'^(?P<slug>[\w,-]+)/$', IParapheurDetailView.as_view(),
        name='iparapheur-view'),
    url(r'^(?P<slug>[\w,-]+)/ping/$', PingView.as_view(),
        name='iparapheur-ping'),
    url(r'^(?P<slug>[\w,-]+)/types/$', TypesView.as_view(),
        name='iparapheur-types'),
    url(r'^(?P<slug>[\w,-]+)/subtypes/$', SubTypesView.as_view(),
        name='iparapheur-subtypes'),
    url(r'^(?P<slug>[\w,-]+)/files/$', ListFiles.as_view(),
        name='iparapheur-list-files'),
    url(r'^(?P<slug>[\w,-]+)/create-file/$', CreateFile.as_view(),
        name='iparapheur-create-file'),
    url(r'^(?P<slug>[\w,-]+)/get-file/(?P<file_id>[\w-]+)/$', FileView.as_view(),
        name='iparapheur-get-file'),
    url(r'^(?P<slug>[\w,-]+)/get-file-status/(?P<file_id>[\w-]+)/$', FileStatusView.as_view(),
        name='iparapheur-get-file-status'),
)

management_urlpatterns = patterns('',
    url(r'^add$', IParapheurCreateView.as_view(),
        name='iparapheur-add'),
    url(r'^(?P<slug>[\w,-]+)/edit$', IParapheurUpdateView.as_view(),
        name='iparapheur-edit'),
    url(r'^(?P<slug>[\w,-]+)/delete$', IParapheurDeleteView.as_view(),
        name='iparapheur-delete'),
)

urlpatterns = required(
    app_enabled('iparapheur'),
    patterns('',
        url(r'^iparapheur/', include(public_urlpatterns)),
        url(r'^manage/iparapheur/',
            decorated_includes(login_required, include(management_urlpatterns))),
    )
)
